@@ -13,8 +13,8 @@
 
 """Routines for configuring Heat."""
 import os
+import socket
 
-from eventlet.green import socket
 from oslo_config import cfg
 from oslo_db import options as oslo_db_ops
 from oslo_log import log as logging
@@ -39,12 +39,14 @@ service_opts = [
     cfg.IntOpt('periodic_interval',
                default=60,
                help=_('Seconds between running periodic tasks.')),
-    cfg.StrOpt('heat_metadata_server_url',
+    cfg.URIOpt('heat_metadata_server_url',
+               schemes=['http', 'https'],
                help=_('URL of the Heat metadata server. '
                       'NOTE: Setting this is only needed if you require '
                       'instances to use a different endpoint than in the '
                       'keystone catalog')),
-    cfg.StrOpt('heat_waitcondition_server_url',
+    cfg.URIOpt('heat_waitcondition_server_url',
+               schemes=['http', 'https'],
                help=_('URL of the Heat waitcondition server.')),
     cfg.StrOpt('instance_connection_is_secure',
                default="0",
@@ -238,12 +240,20 @@ engine_opts = [
                       ' for stack locking.')),
     cfg.BoolOpt('enable_stack_abandon',
                 default=False,
+                deprecated_for_removal=True,
+                deprecated_reason="Stack abandon is not supported by "
+                                  "convergence engine.",
                 help=_('Enable the preview Stack Abandon feature.')),
     cfg.BoolOpt('enable_stack_adopt',
                 default=False,
+                deprecated_for_removal=True,
+                deprecated_reason="Stack adopt is not supported by "
+                                  "convergence engine.",
                 help=_('Enable the preview Stack Adopt feature.')),
     cfg.BoolOpt('convergence_engine',
                 default=True,
+                deprecated_for_removal=True,
+                deprecated_reason='Legacy engine has been deprecated.',
                 help=_('Enables engine with convergence architecture. All '
                        'stacks with this option will be created using '
                        'convergence engine.')),
@@ -397,16 +407,16 @@ clients_opts = [
                        "be verified."))]
 
 heat_client_opts = [
-    cfg.StrOpt('url',
-               default='',
+    cfg.URIOpt('url',
+               schemes=['http', 'https'],
                help=_('Optional heat url in format like'
-                      ' http://0.0.0.0:8004/v1/%(tenant_id)s.'))]
+                      ' http://127.0.0.1:8004/v1/%(tenant_id)s.'))]
 
 keystone_client_opts = [
-    cfg.StrOpt('auth_uri',
-               default='',
+    cfg.URIOpt('auth_uri',
+               schemes=['http', 'https'],
                help=_('Unversioned keystone url in format like'
-                      ' http://0.0.0.0:5000.'))]
+                      ' http://127.0.0.1:5000.'))]
 
 client_http_log_debug_opts = [
     cfg.BoolOpt('http_log_debug',
@@ -474,10 +484,9 @@ def list_opts():
     yield noauth_group.name, noauth_opts
     yield 'clients', default_clients_opts
 
-    for client in ('aodh', 'barbican', 'cinder', 'designate',
-                   'glance', 'heat', 'keystone', 'magnum', 'manila', 'mistral',
-                   'monasca', 'neutron', 'nova', 'octavia',
-                   'swift', 'trove', 'vitrage', 'zaqar'
+    for client in ('aodh', 'barbican', 'cinder', 'designate', 'glance', 'heat',
+                   'keystone', 'magnum', 'manila', 'mistral', 'neutron',
+                   'nova', 'octavia', 'swift', 'trove', 'vitrage', 'zaqar'
                    ):
         client_specific_group = 'clients_' + client
         yield client_specific_group, clients_opts
@@ -535,7 +544,7 @@ def load_paste_app(app_name=None):
 
     # append the deployment flavor to the application name,
     # in order to identify the appropriate paste pipeline
-    app_name += _get_deployment_flavor()
+    app_name_flavor = app_name + _get_deployment_flavor()
 
     conf_file = _get_deployment_config_file()
     if conf_file is None:
@@ -543,23 +552,25 @@ def load_paste_app(app_name=None):
                            cfg.CONF.paste_deploy['api_paste_config'])
 
     try:
-        app = wsgi.paste_deploy_app(conf_file, app_name, cfg.CONF)
-
-        # Log the options used when starting if we're in debug mode...
-        if cfg.CONF.debug:
-            cfg.CONF.log_opt_values(logging.getLogger(app_name),
-                                    logging.DEBUG)
-
-        return app
+        try:
+            app = wsgi.paste_deploy_app(conf_file, app_name_flavor, cfg.CONF)
+        except LookupError:
+            app = wsgi.paste_deploy_app(conf_file, app_name, cfg.CONF)
     except (LookupError, ImportError) as e:
-        raise RuntimeError(_("Unable to load %(app_name)s from "
-                             "configuration file %(conf_file)s."
-                             "\nGot: %(e)r") % {'app_name': app_name,
-                                                'conf_file': conf_file,
-                                                'e': e})
+        raise RuntimeError(
+            _("Unable to load %(app_name)s from configuration file "
+              "%(conf_file)s.\nGot: %(e)r") % {'app_name': app_name_flavor,
+                                               'conf_file': conf_file,
+                                               'e': e})
+
+    # Log the options used when starting if we're in debug mode...
+    if cfg.CONF.debug:
+        cfg.CONF.log_opt_values(logging.getLogger(app_name),
+                                logging.DEBUG)
+    return app
 
 
-def get_client_option(client, option):
+def get_client_option(client, option, fallback=True):
     # look for the option in the [clients_${client}] section
     # unknown options raise cfg.NoSuchOptError
     try:
@@ -567,9 +578,11 @@ def get_client_option(client, option):
         cfg.CONF.import_opt(option, 'heat.common.config',
                             group=group_name)
         v = getattr(getattr(cfg.CONF, group_name), option)
-        if v is not None:
+        if not fallback or v is not None:
             return v
     except cfg.NoSuchGroupError:
+        if not fallback:
+            raise
         pass  # do not error if the client is unknown
     # look for the option in the generic [clients] section
     cfg.CONF.import_opt(option, 'heat.common.config', group='clients')
